============
Installation
============

At the command line::

    $ easy_install flask-htmlbuilder

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv flask-htmlbuilder
    $ pip install flask-htmlbuilder
